==> mariadb-connector-odbc-3.1.17-src.zip: mariadb-connector-odbc-3.1.17-src/dsn/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by odbc_dsn.rc
//
#define PB_NEXT                         3
#define IDCANCEL3                       4
#define PB_PREV                         5
#define IDCANCEL4                       6
#define IDD_DIALOG1                     101
#define Tab_DSN                         102
#define Page_0                          103
#define Tab_Cursor                      104
#define IDB_BITMAP1                     105
#define Tab_Metadata                    106
#define Tab_Connection                  108
#define Tab_Connect                     109
#define Page_1                          110
#define Page_2                          111
#define Page_3                          112
#define Page_4                          114
#define Page_5                          115
#define DSN_Name                        1002
#define DSN_Description                 1003
#define DSN_Database                    1005
#define DSN_UserName                    1013
#define DSN_Password                    1014
#define DSN_Test                        1015
#define IDC_CHECK2                      1017
#define rbTCP                           1018
#define IDC_CHECK3                      1019
#define rbPipe                          1020
#define IDC_CHECK4                      1021
#define txtServerName                   1022
#define IDC_CHECK5                      1023
#define lblServerName                   1024
#define txtPort                         1026
#define lblPort                         1028
#define IDC_CHECK8                      1029
#define IDC_CHECK9                      1030
#define txtServer                       1031
#define txtUserName                     1032
#define IDC_EDIT4                       1033
#define txtPassword                     1034
#define pbTestDSN                       1035
#define IDC_COMBO1                      1036
#define cbDatabase                      1037
#define txtInitCmd                      1038
#define ckReconnect                     1039
#define cbCharset                       1040
#define ckConnectPrompt                 1041
#define IDC_EDIT1                       1042
#define txtConnectionTimeOut            1043
#define txtReadTimeOut                  1230
#define txtWriteTimeOut                 1231
#define txtDriver                       1200
#define ckEnableDC                      1045
#define ckReconnect2                    1046
#define ckDisableDriverCursorSupport    1047
#define ckNoCacheForwardOnly            1048
#define ckPrefetch                      1049
#define IckUseIS                        1050
#define ckUseIS                         1051
#define ckIgnoreSchema                  1052
#define txtDsnName                      1053
#define txtDSNDescription               1054
#define ckEnableDynamicCursor           1100
#define ckDisableDriverCursor           1101
#define ckDontCacheForwardCursor        1102
#define ckForwardCursorOnly             1103
#define ckReturnMatchedRows             1104
#define ckEnableSQLAutoIsNull           1105
#define ckPadCharFullLength             1106
#define ckNullDate                      1107
#define ckPrefetchRows                  1108
#define ckCompressed                    1109
#define ckDebug                         1110
#define ckPrefetchRows2                 1111
#define ckIgnoreSpace                   1112
#define ckMultiStmt                     1113
#define ckMatchedRows                   1114
#define txtPluginDir                    1115
#define pbPlugindirBrowse               1116
#define ckSchParamNoError               1221
#define ckNoLocalInfile                 1310
#define ckNullSchemaMeansCurrent        1222
#define txtSslKey                       1117
#define txtSslCert                      1118
#define txtSslCertAuth                  1119
#define txtSslCaPath                    1120
#define txtSslCipher                    1121
#define cbSslVerify                     1122
#define pbCaPathBrowse                  1123
#define pbKeyBrowse                     1124
#define pbCertBrowse                    1125
#define pbCaCertBrowse                  1126
#define ckUseMycnf                      1127
/* TLSVERSION checkbox group. Id determines bit */
#define cbTls11                         1128
#define cbTls12                         1129
#define cbTls13                         1131
/* End of TLSVERSION */
#define cbForceTls                      1300
#define txtServerKey                    1200
#define pbServerKeyBrowse               1201
#define txtTlsPeerFp                    1210
#define txtTlsPeerFpList                1211
#define pbFpListBrowse                  1212
#define txtCrl                          1213
#define pbCrlBrowse                     1214
#define cbInteractive                   1220

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        107
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1044
#define _APS_NEXT_SYMED_VALUE           113
#endif
#endif

==> mariadb-connector-odbc-3.1.19-src.zip: mariadb-connector-odbc-3.1.19-src/dsn/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by odbc_dsn.rc
//
#define PB_NEXT                         3
#define IDCANCEL3                       4
#define PB_PREV                         5
#define IDCANCEL4                       6
#define IDD_DIALOG1                     101
#define Tab_DSN                         102
#define Page_0                          103
#define Tab_Cursor                      104
#define IDB_BITMAP1                     105
#define Tab_Metadata                    106
#define Tab_Connection                  108
#define Tab_Connect                     109
#define Page_1                          110
#define Page_2                          111
#define Page_3                          112
#define Page_4                          114
#define Page_5                          115
#define DSN_Name                        1002
#define DSN_Description                 1003
#define DSN_Database                    1005
#define DSN_UserName                    1013
#define DSN_Password                    1014
#define DSN_Test                        1015
#define IDC_CHECK2                      1017
#define rbTCP                           1018
#define IDC_CHECK3                      1019
#define rbPipe                          1020
#define IDC_CHECK4                      1021
#define txtServerName                   1022
#define txtSocket                       1031
#define IDC_CHECK5                      1023
#define lblServerName                   1024
#define txtPort                         1026
#define lblPort                         1028
#define IDC_CHECK8                      1029
#define IDC_CHECK9                      1030
#define txtUserName                     1032
#define IDC_EDIT4                       1033
#define txtPassword                     1034
#define pbTestDSN                       1035
#define IDC_COMBO1                      1036
#define cbDatabase                      1037
#define txtInitCmd                      1038
#define ckReconnect                     1039
#define cbCharset                       1040
#define ckConnectPrompt                 1041
#define IDC_EDIT1                       1042
#define txtConnectionTimeOut            1043
#define txtReadTimeOut                  1230
#define txtWriteTimeOut                 1231
#define txtDriver                       1200
#define ckEnableDC                      1045
#define ckReconnect2                    1046
#define ckDisableDriverCursorSupport    1047
#define ckNoCacheForwardOnly            1048
#define ckPrefetch                      1049
#define IckUseIS                        1050
#define ckUseIS                         1051
#define ckIgnoreSchema                  1052
#define txtDsnName                      1053
#define txtDSNDescription               1054
#define ckEnableDynamicCursor           1100
#define ckDisableDriverCursor           1101
#define ckDontCacheForwardCursor        1102
#define ckForwardCursorOnly             1103
#define ckReturnMatchedRows             1104
#define ckEnableSQLAutoIsNull           1105
#define ckPadCharFullLength             1106
#define ckNullDate                      1107
#define ckPrefetchRows                  1108
#define ckCompressed                    1109
#define ckDebug                         1110
#define ckPrefetchRows2                 1111
#define ckIgnoreSpace                   1112
#define ckMultiStmt                     1113
#define ckMatchedRows                   1114
#define txtPluginDir                    1115
#define pbPlugindirBrowse               1116
#define ckSchParamNoError               1221
#define ckNoLocalInfile                 1310
#define ckNullSchemaMeansCurrent        1222
#define txtSslKey                       1117
#define txtSslCert                      1118
#define txtSslCertAuth                  1119
#define txtSslCaPath                    1120
#define txtSslCipher                    1121
#define cbSslVerify                     1122
#define pbCaPathBrowse                  1123
#define pbKeyBrowse                     1124
#define pbCertBrowse                    1125
#define pbCaCertBrowse                  1126
#define ckUseMycnf                      1127
/* TLSVERSION checkbox group. Id determines bit */
#define cbTls11                         1128
#define cbTls12                         1129
#define cbTls13                         1131
/* End of TLSVERSION */
#define cbForceTls                      1300
#define txtServerKey                    1200
#define pbServerKeyBrowse               1201
#define txtTlsPeerFp                    1210
#define txtTlsPeerFpList                1211
#define pbFpListBrowse                  1212
#define txtCrl                          1213
#define pbCrlBrowse                     1214
#define cbInteractive                   1220

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        107
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1044
#define _APS_NEXT_SYMED_VALUE           113
#endif
#endif
